.. Metallurgy documentation master file, created by
   sphinx-quickstart on Fri Apr  8 10:44:15 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. mdinclude:: ../../README.md

.. toctree::
   :caption: API Reference
   :hidden:

   api.rst

Index
=====

* :ref:`genindex`
* :ref:`modindex`
